Release History
===============


1.1 - 2016-11-20
----------------------

* New: ``say()`` function that eliminates formatting problems in printing
  multi-line prose.
* New: :meth:`get_random()` and :meth:`take_random()` functions to allow
  randomly selecting items from a :class:`Bag`.
* Fix: a bug where ``@when`` statements match even if extra words are given.
* Fix: Bag find/get methods were not properly case-insensitive.


1.0 - 2016-10-01
----------------

Initial public release.
